@@ -45,11 +45,14 @@
 #define HELPER_ID "org.kde.powerdevil.backlighthelper"
 
 PowerDevilUPowerBackend::PowerDevilUPowerBackend(QObject* parent)
-    : BackendInterface(parent),
-      m_displayDevice(Q_NULLPTR),
-      m_brightnessControl(Q_NULLPTR),
-      m_kbdMaxBrightness(0),
-      m_lidIsPresent(false), m_lidIsClosed(false), m_onBattery(false)
+    : BackendInterface(parent)
+    , m_displayDevice(Q_NULLPTR)
+    , m_brightnessControl(Q_NULLPTR)
+    , m_randrHelper(Q_NULLPTR)
+    , m_upowerInterface(Q_NULLPTR)
+    , m_kbdBacklight(Q_NULLPTR)
+    , m_kbdMaxBrightness(0)
+    , m_lidIsPresent(false), m_lidIsClosed(false), m_onBattery(false)
 {
 
 }
@@ -201,22 +204,22 @@ void PowerDevilUPowerBackend::init()
         Q_ASSERT(m_randrHelper);
         connect(m_randrHelper, &XRandRXCBHelper::brightnessChanged, this, &PowerDevilUPowerBackend::slotScreenBrightnessChanged);
         m_cachedBrightnessMap.insert(Screen, brightness(Screen));
-
-        const int duration = PowerDevilSettings::brightnessAnimationDuration();
-        if (duration > 0 && brightnessMax() >= PowerDevilSettings::brightnessAnimationThreshold()) {
-            m_brightnessAnimation = new QPropertyAnimation(this);
-            m_brightnessAnimation->setTargetObject(this);
-            m_brightnessAnimation->setDuration(duration);
-            m_brightnessAnimation->setEasingCurve(QEasingCurve::InOutQuad);
-            connect(m_brightnessAnimation, &QPropertyAnimation::valueChanged, this, &PowerDevilUPowerBackend::animationValueChanged);
-            connect(m_brightnessAnimation, &QPropertyAnimation::finished, this, &PowerDevilUPowerBackend::slotScreenBrightnessChanged);
-        }
         emit brightnessSupportQueried(true);
     }
 }
 
 void PowerDevilUPowerBackend::initWithBrightness(bool screenBrightnessAvailable)
 {
+    const int duration = PowerDevilSettings::brightnessAnimationDuration();
+    if (duration > 0 && brightnessMax() >= PowerDevilSettings::brightnessAnimationThreshold()) {
+        m_brightnessAnimation = new QPropertyAnimation(this);
+        m_brightnessAnimation->setTargetObject(this);
+        m_brightnessAnimation->setDuration(duration);
+        m_brightnessAnimation->setEasingCurve(QEasingCurve::InOutQuad);
+        connect(m_brightnessAnimation, &QPropertyAnimation::valueChanged, this, &PowerDevilUPowerBackend::animationValueChanged);
+        connect(m_brightnessAnimation, &QPropertyAnimation::finished, this, &PowerDevilUPowerBackend::slotScreenBrightnessChanged);
+    }
+
     disconnect(this, &PowerDevilUPowerBackend::brightnessSupportQueried, this, &PowerDevilUPowerBackend::initWithBrightness);
     // Capabilities
     setCapabilities(SignalResumeFromSuspend);
@@ -269,17 +272,17 @@ void PowerDevilUPowerBackend::initWithBrightness(bool screenBrightnessAvailable)
     if (m_login1Interface) {
         QDBusPendingReply<QString> canSuspend = m_login1Interface.data()->asyncCall("CanSuspend");
         canSuspend.waitForFinished();
-        if (canSuspend.isValid() && (canSuspend.value() == "yes" || canSuspend.value() == "challenge"))
+        if (canSuspend.isValid() && (canSuspend.value() == QLatin1String("yes") || canSuspend.value() == QLatin1String("challenge")))
             supported |= ToRam;
 
         QDBusPendingReply<QString> canHibernate = m_login1Interface.data()->asyncCall("CanHibernate");
         canHibernate.waitForFinished();
-        if (canHibernate.isValid() && (canHibernate.value() == "yes" || canHibernate.value() == "challenge"))
+        if (canHibernate.isValid() && (canHibernate.value() == QLatin1String("yes") || canHibernate.value() == QLatin1String("challenge")))
             supported |= ToDisk;
 
         QDBusPendingReply<QString> canHybridSleep = m_login1Interface.data()->asyncCall("CanHybridSleep");
         canHybridSleep.waitForFinished();
-        if (canHybridSleep.isValid() && (canHybridSleep.value() == "yes" || canHybridSleep.value() == "challenge"))
+        if (canHybridSleep.isValid() && (canHybridSleep.value() == QLatin1String("yes") || canHybridSleep.value() == QLatin1String("challenge")))
             supported |= HybridSuspend;
     }
 
@@ -303,9 +306,10 @@ void PowerDevilUPowerBackend::initWithBrightness(bool screenBrightnessAvailable)
 
     // "resuming" signal
     if (m_login1Interface && !m_useUPowerSuspend) {
-        connect(m_login1Interface.data(), SIGNAL(PrepareForSleep(bool)), this, SLOT(slotLogin1Resuming(bool)));
+        connect(m_login1Interface.data(), SIGNAL(PrepareForSleep(bool)), this, SLOT(slotLogin1PrepareForSleep(bool)));
     } else {
-        connect(m_upowerInterface, SIGNAL(Resuming()), this, SIGNAL(resumeFromSuspend()));
+        connect(m_upowerInterface, &OrgFreedesktopUPowerInterface::Sleeping, this, &PowerDevilUPowerBackend::aboutToSuspend);
+        connect(m_upowerInterface, &OrgFreedesktopUPowerInterface::Resuming, this, &PowerDevilUPowerBackend::resumeFromSuspend);
     }
 
     // battery
@@ -323,6 +327,11 @@ void PowerDevilUPowerBackend::initWithBrightness(bool screenBrightnessAvailable)
 void PowerDevilUPowerBackend::onDeviceChanged(const UdevQt::Device &device)
 {
     qCDebug(POWERDEVIL) << "Udev device changed" << m_syspath << device.sysfsPath();
+
+    if (m_brightnessAnimation && m_brightnessAnimation->state() != QPropertyAnimation::Stopped) {
+        return;
+    }
+
     if (device.sysfsPath() != m_syspath) {
         return;
     }
@@ -352,9 +361,7 @@ int PowerDevilUPowerBackend::brightnessKeyPressed(PowerDevil::BrightnessLogic::B
     // m_cachedBrightnessMap is not being updated during animation, thus checking the m_cachedBrightnessMap
     // value here doesn't make much sense, use the endValue from brightness() anyway.
     // This prevents brightness key being ignored during the animation.
-    if (!(controlType == Screen &&
-          m_brightnessAnimation &&
-          m_brightnessAnimation->state() == QPropertyAnimation::Running) &&
+    if (!(controlType == Screen && m_brightnessAnimation && m_brightnessAnimation->state() == QPropertyAnimation::Running) &&
         currentBrightness != m_cachedBrightnessMap.value(controlType)) {
         m_cachedBrightnessMap[controlType] = currentBrightness;
         return currentBrightness;
@@ -376,13 +383,10 @@ int PowerDevilUPowerBackend::brightness(PowerDevil::BackendInterface::Brightness
     int result = 0;
 
     if (type == Screen) {
-        if (m_brightnessControl->isSupported()) {
-            if (m_brightnessAnimation && m_brightnessAnimation->state() == QPropertyAnimation::Running) {
-                result = m_brightnessAnimation->endValue().toInt();
-            } else {
-                //qCDebug(POWERDEVIL) << "Calling xrandr brightness";
-                result = (int) m_brightnessControl->brightness();
-            }
+        if (m_brightnessAnimation && m_brightnessAnimation->state() == QPropertyAnimation::Running) {
+            result = m_brightnessAnimation->endValue().toInt();
+        } else if (m_brightnessControl->isSupported()) {
+            result = (int) m_brightnessControl->brightness();
         } else {
             result = m_cachedBrightnessMap[Screen];
         }
@@ -419,25 +423,16 @@ void PowerDevilUPowerBackend::setBrightness(int value, PowerDevil::BackendInterf
 {
     if (type == Screen) {
         qCDebug(POWERDEVIL) << "set screen brightness value: " << value;
-        if (m_brightnessControl->isSupported()) {
-            if (m_brightnessAnimation) {
-                m_brightnessAnimation->stop();
-                disconnect(m_brightnessAnimation, &QPropertyAnimation::valueChanged, this, &PowerDevilUPowerBackend::animationValueChanged);
-                m_brightnessAnimation->setStartValue(brightness());
-                m_brightnessAnimation->setEndValue(value);
-                connect(m_brightnessAnimation, &QPropertyAnimation::valueChanged, this, &PowerDevilUPowerBackend::animationValueChanged);
-                m_brightnessAnimation->start();
-            } else {
-                m_brightnessControl->setBrightness(value);
-            }
+
+        if (m_brightnessAnimation) {
+            m_brightnessAnimation->stop();
+            disconnect(m_brightnessAnimation, &QPropertyAnimation::valueChanged, this, &PowerDevilUPowerBackend::animationValueChanged);
+            m_brightnessAnimation->setStartValue(brightness());
+            m_brightnessAnimation->setEndValue(value);
+            connect(m_brightnessAnimation, &QPropertyAnimation::valueChanged, this, &PowerDevilUPowerBackend::animationValueChanged);
+            m_brightnessAnimation->start();
         } else {
-            //qCDebug(POWERDEVIL) << "Falling back to helper to set brightness";
-            KAuth::Action action("org.kde.powerdevil.backlighthelper.setbrightness");
-            action.setHelperId(HELPER_ID);
-            action.addArgument("brightness", value);
-            KAuth::ExecuteJob *job = action.execute();
-            // we don't care about the result since executing the job sync is bad
-            job->start();
+            animationValueChanged(value);
         }
     } else if (type == Keyboard) {
         qCDebug(POWERDEVIL) << "set kbd backlight value: " << value;
@@ -644,14 +639,25 @@ void PowerDevilUPowerBackend::onDevicePropertiesChanged(const QString &ifaceName
     }
 }
 
-void PowerDevilUPowerBackend::slotLogin1Resuming(bool active)
+void PowerDevilUPowerBackend::slotLogin1PrepareForSleep(bool active)
 {
-    if (!active) {
+    if (active) {
+        emit aboutToSuspend();
+    } else {
         emit resumeFromSuspend();
     }
 }
 
 void PowerDevilUPowerBackend::animationValueChanged(const QVariant &value)
 {
-    m_brightnessControl->setBrightness(value.toInt());
+    if (m_brightnessControl->isSupported()) {
+        m_brightnessControl->setBrightness(value.toInt());
+    } else {
+        KAuth::Action action("org.kde.powerdevil.backlighthelper.setbrightness");
+        action.setHelperId(HELPER_ID);
+        action.addArgument("brightness", value.toInt());
+        KAuth::ExecuteJob *job = action.execute();
+        // we don't care about the result since executing the job sync is bad
+        job->start();
+    }
 }
